Pikaday alignment example
Author: Maxime Thirouin

# Pikaday alignement example

A refreshing JavaScript Datepicker — lightweight, no dependencies, modular CSS.

Dates:
not really (too close from top)
for real this time (same code as above)
not really (too close from right)
Here is the top right position with content before (no automatic adjustment used, same code as above)
Here is the bottom right position with content before (no automatic adjustment used, , same code as above)

Also, take a look to the bottom right of this page to see an example with position automatically adjusted.

## What is this?

Since version 1.0 Pikaday is a stable and battle tested date-picker. Feel free to use it however you like but please report any bugs or feature requests to the GitHub issue tracker, thanks!

Copyright © 2014 David Bushell | BSD & MIT license | Example by MoOx